@@ -2,12 +2,23 @@ from pydantic import BaseModel, Field
 from typing import Optional
 
 
+class CustomerBillingConfiguration(BaseModel):
+    invoice_grace_period: Optional[int]
+    payment_provider: Optional[str]
+    provider_customer_id: Optional[str]
+    vat_rate: Optional[float]
+    sync: Optional[bool]
+    sync_with_provider: Optional[bool]
+    document_locale: Optional[str]
+
+
 class Customer(BaseModel):
-    customer_id: str
+    external_id: str
     address_line1: Optional[str]
     address_line2: Optional[str]
     city: Optional[str]
     country: Optional[str]
+    currency: Optional[str]
     email: Optional[str]
     legal_name: Optional[str]
     legal_number: Optional[str]
@@ -15,18 +26,20 @@ class Customer(BaseModel):
     name: str
     phone: Optional[str]
     state: Optional[str]
+    timezone: Optional[str]
     url: Optional[str]
-    vat_rate: Optional[float]
     zipcode: Optional[str]
+    billing_configuration: Optional[CustomerBillingConfiguration]
 
 
 class CustomerResponse(BaseModel):
     lago_id: str
-    customer_id: str
+    external_id: str
     address_line1: Optional[str]
     address_line2: Optional[str]
     city: Optional[str]
     country: Optional[str]
+    currency: Optional[str]
     email: Optional[str]
     created_at: str
     legal_name: Optional[str]
@@ -35,6 +48,8 @@ class CustomerResponse(BaseModel):
     name: str
     phone: Optional[str]
     state: Optional[str]
+    timezone: Optional[str]
+    applicable_timezone: str
     url: Optional[str]
-    vat_rate: Optional[float]
     zipcode: Optional[str]
+    billing_configuration: Optional[CustomerBillingConfiguration]
